@@ -1,8 +1,8 @@
 #include "append_list.h"
+#include "xmalloc.h"
 #include "struct_OPArg.h"
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <limits.h>
 
 #include <errno.h>
@@ -28,7 +28,7 @@
 	}\
 }
 
-// 関数プロトタイプ
+/* 関数プロトタイプ */
 void analyze_argument(const int argc, char **argv, OPArg *oparg);
 
 /*******************************************************************************
@@ -39,12 +39,12 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 {
 	int result;
 
-	// 引数解析
-	while((result = getopt(argc, argv, "1:5:0b:c:iIlLmMor:t:vw:")) != -1)
+	/* 引数解析 */
+	while((result = getopt(argc, argv, "1:5:0b:iIlLmMor:t:vw:")) != -1)
 	{
 		switch(result)
 		{
-		case '1':	// SHA1SUMでチェックする
+		case '1':	/* SHA1SUMでチェックする */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -54,7 +54,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			HASH_CHECK_MODE_SET
 			break;
 
-		case '5':	// MD5SUMでチェックする
+		case '5':	/* MD5SUMでチェックする */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -64,7 +64,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			HASH_CHECK_MODE_SET
 			break;
 
-		case '0':	// コンペアを行わない
+		case '0':	/* コンペアを行わない */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -73,7 +73,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			oparg->CHECK_MODE = NOT;
 			break;
 
-		case 'b':	// バッファサイズを指定
+		case 'b':	/* バッファサイズを指定 */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -81,7 +81,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			{
 				char *endptr = NULL;
 				errno = 0;
-				// atoiは使うべきではない、らしい
+				/* atoiは使うべきではない、らしい */
 				off_t b_tmp = strtoll(optarg, &endptr, 10);
 
 				if(b_tmp > INT_MAX)
@@ -101,7 +101,8 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			}
 			break;
 
-		case 'c':	// memcmpでチェックする
+//		case 'c':	/* memcmpでチェックする */
+/*
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -110,8 +111,8 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 
 			HASH_CHECK_MODE_SET
 			break;
-
-		case 'i':	// 上書き時に確認する
+*/
+		case 'i':	/* 上書き時に確認する */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -120,7 +121,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			oparg->WRITE_MODE = OVERWRITE;
 			break;
 
-		case 'I':	// -iを無効
+		case 'I':	/* -iを無効 */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -128,7 +129,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			oparg->I = NOT;
 			break;
 
-		case 'l':	// コンペアのログを保存する
+		case 'l':	/* コンペアのログを保存する */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -136,7 +137,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			oparg->L = LOG;
 			break;
 
-		case 'L':	// -lを無効にする
+		case 'L':	/* -lを無効にする */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -144,7 +145,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			oparg->L = NOT;
 			break;
 
-		case 'm':	// 移動モード
+		case 'm':	/* 移動モード */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -152,7 +153,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			oparg->M = MOVE;
 			break;
 
-		case 'M':	// 移動モード無効
+		case 'M':	/* 移動モード無効 */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -160,7 +161,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			oparg->M = NOT;
 			break;
 
-		case 'o':	// オプションの設定
+		case 'o':	/* オプションの設定 */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -168,7 +169,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			fprintf(stderr, "-oオプションは無視されます\n");
 			break;
 
-		case 'r':	// MD5SUMでチェックする
+		case 'r':	/* MD5SUMでチェックする */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -178,7 +179,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			HASH_CHECK_MODE_SET
 			break;
 
-		case 't':	// スレッドモード
+		case 't':	/* スレッドモード */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -204,7 +205,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			}
 			break;
 
-		case 'v':	// 表示モード
+		case 'v':	/* 表示モード */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -212,7 +213,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			oparg->V = VERBOS;
 			break;
 
-		case 'w':	// 上書きモード
+		case 'w':	/* 上書きモード */
 			if(oparg->EFFECT == NOT)
 			{
 				oparg->EFFECT = EXIST;
@@ -243,7 +244,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			}
 			break;
 
-		case '?':	// 未知のオプション
+		case '?':	/* 未知のオプション */
 			fprintf(stderr, "オプションが正しくありません\n");
 			exit(EXIT_FAILURE);
 			break;
@@ -277,7 +278,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 	oparg->toindex = argc - 1;
 	oparg->argv = argv;
 
-	// コピー元の数をチェック
+	/* コピー元の数をチェック */
 	{
 		off_t index_tmp = oparg->toindex;
 		off_t count_tmp = 0;
@@ -297,7 +298,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 		{
 			if((size % psize) == 0)
 			{
-				int *i = malloc(sizeof(int));
+				int *i = xmalloc(sizeof(int));
 				*i = size;
 				b_size_list = append_list(b_size_list, i);
 			}
