@@ -190,6 +190,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 	cpdd->total_read = 0;
 	cpdd->total_write = 0;
 	cpdd->total_error = 0;
+	cpdd->thread_mode_count = 0;
 
 	char tmp_from[PATH_MAX];
 	char tmp_to[PATH_MAX];
@@ -1019,6 +1020,34 @@ static inline void fgets_is_null(void)
 	exit(EXIT_FAILURE);
 }
 
+/******************************************************************************
+*******************************************************************************/
+#define PATH_CHECK \
+const char *mp = tmp->mount_point;\
+_Bool flag = false;\
+\
+for(;;)\
+{\
+	if(*path == *mp)\
+	{\
+		path++;\
+		mp++;\
+	}\
+	else \
+	{\
+		break;\
+	}\
+\
+	if(*mp == '\0')\
+	{\
+		if((*path == G_DIR_SEPARATOR) || (*path == '\0'))\
+		{\
+			flag = true;\
+		}\
+		break;\
+	}\
+}
+
 /******************************************************************************
  * ドライブが同一かどうか調べる
 *******************************************************************************/
@@ -1035,19 +1064,50 @@ static inline void set_same_or_different(const VList *drive_list, const char *fr
 	for(;;)
 	{
 		DPath *tmp = (DPath *)tmplist->data;
-		int tmplen = strlen(tmp->mount_point);
-
-		if(strncmp(tmp->mount_point, from, tmplen) == 0)
+/*
+printf("%s %s\n", tmp->device, tmp->mount_point);
+*/
+		if((tmp->mount_point[1] == '\0') && (tmp->mount_point[0] == G_DIR_SEPARATOR))
 		{
-			fromdev = tmp->device;
+			if(fromdev == NULL)
+			{
+				fromdev = tmp->device;
+			}
+
+			if(todev == NULL)
+			{
+				todev = tmp->device;
+				cpinfo->tofs = tmp->fs;
+			}
+
+			goto DEV_CHECK_SKIP;
 		}
 
-		if(strncmp(tmp->mount_point, to, tmplen) == 0)
 		{
-			todev = tmp->device;
-			cpinfo->tofs = tmp->fs;
+			const char *path = from;
+
+			PATH_CHECK
+
+			if(flag == true)
+			{
+				fromdev = tmp->device;
+			}
 		}
 
+		{
+			const char *path = to;
+
+			PATH_CHECK
+
+			if(flag == true)
+			{
+				todev = tmp->device;
+				cpinfo->tofs = tmp->fs;
+			}
+		}
+
+DEV_CHECK_SKIP:
+;
 		if(tmplist->next != NULL)
 		{
 			tmplist = tmplist->next;
