@@ -37,7 +37,7 @@ static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD
 	{
 		check = c_s(oparg, cpinfo, cpdd);
 	}
-	else
+	else if(link_check == TRUE)
 	{
 		if(oparg->WRITE_MODE == OVERWRITE)
 		{
@@ -127,6 +127,12 @@ static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD
 			}
 		}
 	}
+	else
+	{
+		printf("%s をスキップします\n", cpinfo->to);
+		fflush(stdout);
+		check = false;
+	}
 
 	cpinfo->write = check;
 }
