@@ -6,7 +6,7 @@
 
 #include <linux/limits.h>
 
-// 関数プロトタイプ
+/* 関数プロトタイプ */
 VList * get_drive_list(void);
 
 /*******************************************************************************
@@ -19,7 +19,7 @@ VList * get_drive_list(void);
 *******************************************************************************/
 VList * get_drive_list(void)
 {
-	DPath *drive_path = NULL;
+	DPath *d_path = NULL;
 	VList *drive_list = NULL;
 	FILE *mtab;
 
@@ -30,7 +30,7 @@ VList * get_drive_list(void)
 	}
 	else
 	{
-		// mtabの一行の最大長をPATH_MAXの3倍と仮定
+		/* mtabの一行の最大長をPATH_MAXの3倍と仮定 */
 		int mtab_line = PATH_MAX * 3;
 		char mtab_buf[mtab_line];
 
@@ -41,21 +41,21 @@ VList * get_drive_list(void)
 				char *tmp = strtok(mtab_buf, " ");
 				int len = strlen(tmp);
 				int lenp1 = (len + 1);
-				drive_path = xmalloc(sizeof(drive_path));
-				drive_path->device = xmalloc(lenp1);
-				memcpy(drive_path->device, tmp, lenp1);
-				// 一文字短く　例：/dev/sda1　→　/dev/sda
-				drive_path->device[len - 1] = '\0';
+				d_path = xmalloc(sizeof(DPath));
+				d_path->device = xmalloc(lenp1);
+				memcpy(d_path->device, tmp, lenp1);
+				/* 一文字短くする。　例：/dev/sda1　→　/dev/sda */
+				d_path->device[len - 1] = '\0';
 
 				tmp = strtok(NULL, " ");
-				drive_path->mount_point = xmalloc(strlen(tmp) + 1);
-				strcpy(drive_path->mount_point, tmp);
+				d_path->mount_point = xmalloc(strlen(tmp) + 1);
+				strcpy(d_path->mount_point, tmp);
 
 				tmp = strtok(NULL, " ");
-				drive_path->fs = xmalloc(strlen(tmp) + 1);
-				strcpy(drive_path->fs, tmp);
+				d_path->fs = xmalloc(strlen(tmp) + 1);
+				strcpy(d_path->fs, tmp);
 
-				drive_list = append_list(drive_list, (void *)drive_path);
+				drive_list = append_list(drive_list, (void *)d_path);
 			}
 		}
 		fclose(mtab);
