@@ -68,6 +68,7 @@ int main(int argc, char **argv)
 	set_signal();
 
 	puts("コピーを開始します...");
+	fflush(stdout);
 
 	RData *rdata = check_target(oparg, drive_list, sdir);
 
@@ -79,10 +80,12 @@ int main(int argc, char **argv)
 	if((file_list != NULL) && (oparg->CHECK_MODE == AFTER) && (cpdd->mk_file_count > 0))
 	{
 		puts("ハッシュ値のチェックを開始します...");
+		fflush(stdout);
 
 		do_compare_verify_two(oparg, file_list, sdir, cpdd);
 
 		puts("ハッシュ値のチェックを完了しました...");
+			fflush(stdout);
 	}
 
 	if(oparg->M == MOVE)
@@ -90,16 +93,22 @@ int main(int argc, char **argv)
 		if((cpdd->mk_file_count > 0) || (cpdd->mk_link_count > 0) || (cpdd->mk_dir_count > 0))
 		{
 			puts("コピー元の削除を開始します...");
+			fflush(stdout);
 
 			delete_from(oparg, file_list, cpdd);
 
 			puts("コピー元の削除を完了しました...");
+			fflush(stdout);
 		}
 	}
 
 	puts("");
 
 	printf("File   : %lld / %lld\n", cpdd->mk_file_count, cpdd->file_count);
+	if(cpdd->thread_mode_count > 0)
+	{
+		printf("Thread : %lld / %lld\n", cpdd->thread_mode_count, cpdd->mk_file_count);
+	}
 	printf("Link   : %lld / %lld\n", cpdd->mk_link_count, cpdd->link_count);
 	printf("Dir    : %lld / %lld\n", cpdd->mk_dir_count, cpdd->dir_count);
 	printf("Source : %lld MB (%lld Bytes)\n", cpdd->total_source / (1024 * 1024), cpdd->total_source);
